BSColumn class

Should be the direct child of a BSRow; however, if required BSColumn can be nested in Widget's with "child" property, BSRow must be an ancestor of BSColumn. BSColumn has a default breakpoint of col-12. If there are two values for a single breakpoint range ex col-sm-1 & col-sm-2, the first in the array will be used. Note only col-, col-sm-, col-md-, col-lg-, col-xl-, col-xxl- prefixes are used. col, or col-md will not work

Inheritance

Constructors

BSColumn({Key? key, List<String> breakPoints = const ["col-12"], List<Widget> builder(BuildContext context)?, double? sizedBoxHeight, Key? sizedBoxKey, Key? paddingKey, EdgeInsetsGeometry paddingPadding = const EdgeInsets.only(left: 15, right: 15), Key? bsColumnInheritanceKey, List<Widget>? children, Key? columnKey, MainAxisSize columnMainAxisSize = MainAxisSize.max, CrossAxisAlignment columnCrossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment columnMainAxisAlignment = MainAxisAlignment.start, TextBaseline? columnTextBaseline, TextDirection? columnTextDirection, VerticalDirection columnVerticalDirection = VerticalDirection.down})
Should be the direct child of a BSRow; however, if required BSColumn can be nested in Widget's with "child" property, BSRow must be an ancestor of BSColumn. BSColumn has a default breakpoint of col-12. If there are two values for a single breakpoint range ex col-sm-1 & col-sm-2, the first in the array will be used. Note only col-, col-sm-, col-md-, col-lg-, col-xl-, col-xxl- prefixes are used. col, or col-md will not work
const

Properties

breakPoints → List<String>
final
bsColumnInheritanceKey → Key?
final
builder → List<Widget> Function(BuildContext context)?
builder for the column passes a build context that can reference the column's inheritance
final
children → List<Widget>?
final
columnCrossAxisAlignment → CrossAxisAlignment
final
columnKey → Key?
final
columnMainAxisAlignment → MainAxisAlignment
final
columnMainAxisSize → MainAxisSize
final
columnTextBaseline → TextBaseline?
final
columnTextDirection → TextDirection?
final
columnVerticalDirection → VerticalDirection
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
paddingKey → Key?
final
paddingPadding → EdgeInsetsGeometry
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizedBoxHeight → double?
final
sizedBoxKey → Key?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited