BSContainer class

Needs to be a child of a Widget that contains MediaQueryData, typically this will be a MaterialApp Acts similarly to a Bootstrap container, can be fluid - match the width of the nearest MediaQueryData parent non-fluid - a static size when the screen is xxl, xl, lg, md, sm - acts the same as fluid if smaller than sm

  • maxWidthIdentifier
    • same as non-fluid, but will never be bigger than the specified breakpoint label
Inheritance

Constructors

BSContainer({Key? key, bool fluid = false, BSBreakPointLabels? maxWidthIdentifier, List<Widget> builder(BuildContext context)?, bool useSingleChildScrollView = true, Key? singleChildScrollViewKey, ScrollController? singleChildScrollViewController, Clip singleChildScrollViewClipBehavior = Clip.hardEdge, EdgeInsetsGeometry? singleChildScrollViewPadding, ScrollPhysics? singleChildScrollViewPhysics, bool? singleChildScrollViewPrimary, String? singleChildScrollViewRestorationId, bool singleChildScrollViewReverse = false, Axis singleChildScrollViewScrollDirection = Axis.vertical, Key? sizedBoxKey, double? height, Key? containerKey, Alignment containerAlignment = Alignment.topCenter, double? containerHeight, double? containerWidth, EdgeInsetsGeometry? containerPadding, Clip containerClipBehavior = Clip.none, Decoration? containerDecoration, Color? containerColor, BoxConstraints? containerConstraints, Decoration? containerForegroundDecoration, EdgeInsetsGeometry? containerMargin, Matrix4? containerTransform, AlignmentGeometry? containerTransformAlignment, Key? bsContainerInheritanceKey, List<Widget>? children, Key? columnKey, VerticalDirection columnVerticalDirection = VerticalDirection.down, TextDirection? columnTextDirection, TextBaseline? columnTextBaseline, MainAxisAlignment columnMainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment columnCrossAxisAlignment = CrossAxisAlignment.center, MainAxisSize columnMainAxisSize = MainAxisSize.max})
Needs to be a child of a Widget that contains MediaQueryData, typically this will be a MaterialApp Acts similarly to a Bootstrap container, can be fluid - match the width of the nearest MediaQueryData parent non-fluid - a static size when the screen is xxl, xl, lg, md, sm - acts the same as fluid if smaller than sm

Properties

bsContainerInheritanceKey → Key?
final
builder → List<Widget> Function(BuildContext context)?
builder for the container passes a build context that can reference the container's inheritance
final
children → List<Widget>?
recommend that children only be BSRow; however, non-BSRow children will be accepted. If the non-BSRow children add width this will produce unexpected results, and may cause errors. It is acceptable to wrap BSRow in a Widget such as a GestureDetector
final
columnCrossAxisAlignment → CrossAxisAlignment
final
columnKey → Key?
final
columnMainAxisAlignment → MainAxisAlignment
final
columnMainAxisSize → MainAxisSize
final
columnTextBaseline → TextBaseline?
final
columnTextDirection → TextDirection?
final
columnVerticalDirection → VerticalDirection
final
containerAlignment → Alignment
final
containerClipBehavior → Clip
final
containerColor → Color?
final
containerConstraints → BoxConstraints?
final
containerDecoration → Decoration?
final
containerForegroundDecoration → Decoration?
final
containerHeight → double?
final
containerKey → Key?
final
containerMargin → EdgeInsetsGeometry?
final
containerPadding → EdgeInsetsGeometry?
final
containerTransform → Matrix4?
final
containerTransformAlignment → AlignmentGeometry?
final
containerWidth → double?
final
fluid → bool
if true the container fills the max amount of it's parent if false (default) the container has it's size set based on how big the nearest parent with a MediaQueryData, which is usually the screen size. See BSContainer.containerWidths
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
passed to the SizedBox, leave as default unless you wish to set a static height for the BSContainer
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidthIdentifier → BSBreakPointLabels?
use an enum value from BSBreakPointLabels to specify what BSContainer.containerWidths size is the max width the BSContainer can be
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleChildScrollViewClipBehavior → Clip
final
singleChildScrollViewController → ScrollController?
final
singleChildScrollViewDragStartBehavior → DragStartBehavior
final
singleChildScrollViewKey → Key?
final
singleChildScrollViewPadding → EdgeInsetsGeometry?
final
singleChildScrollViewPhysics → ScrollPhysics?
final
singleChildScrollViewPrimary → bool?
final
singleChildScrollViewRestorationId → String?
final
singleChildScrollViewReverse → bool
final
singleChildScrollViewScrollDirection → Axis
final
singleChildScrollViewScrollViewKeyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
final
sizedBoxKey → Key?
final
useSingleChildScrollView → bool
default true, wraps container with a SingleChildScrollView. if set to false, there is no SingleChildScrollView, and you can optimize scrolling based on your desires
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited