BSRow class

A row or a column based on it's BSColumn children's breakpoints if the sum of the children column's breakpoints are greater than 12 this is a column, otherwise it is a row

Inheritance

Constructors

BSRow({Key? key, required List<Widget> children, Key? bsRowInheritanceKey, Key? flexKey, MainAxisSize flexMainAxisSize = MainAxisSize.max, CrossAxisAlignment flexCrossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment flexMainAxisAlignment = MainAxisAlignment.start, TextBaseline? flexTextBaseline, TextDirection? flexTextDirection, VerticalDirection flexVerticalDirection = VerticalDirection.down, Clip flexClipBehavior = Clip.none})
A row or a column based on it's BSColumn children's breakpoints if the sum of the children column's breakpoints are greater than 12 this is a column, otherwise it is a row
const

Properties

bsRowInheritanceKey → Key?
final
children → List<Widget>
should be BSColumn. Can also nest BSColumn in Widgets, which have the child property, don't change the width of the BSColumn
final
flexClipBehavior → Clip
final
flexCrossAxisAlignment → CrossAxisAlignment
final
flexKey → Key?
final
flexMainAxisAlignment → MainAxisAlignment
final
flexMainAxisSize → MainAxisSize
final
flexTextBaseline → TextBaseline?
final
flexTextDirection → TextDirection?
final
flexVerticalDirection → VerticalDirection
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited