BSRowInheritance class

The InheritedWidget, which passes data to all the children of BSRowInheritance, allows children to update when BSRowInheritance data updates, usually from a screen resize. The current axis of the row is used to determine the size of children BSColumn

Inheritance

Constructors

BSRowInheritance({Key? key, required Widget child, required Axis currentAxis})
The InheritedWidget, which passes data to all the children of BSRowInheritance, allows children to update when BSRowInheritance data updates, usually from a screen resize. The current axis of the row is used to determine the size of children BSColumn
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
currentAxis → Axis
the current axis of the row, children columns max width if vertical
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant BSRowInheritance oldWidget) → bool
no need to call this function manually usually
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calculateColumnCurrentBreakPointSizeFactor({required BSColumn column, required BSBreakPointLabels currentBreakPointLabel}) → int
get a BSColumn's breakpoint size factor from the columns breakpoints, and the current breakpoint set by the BSContainer ex if current breakpoint xxl, and the column has breakpoints col-md-5, and col-sm-3, 5 will be returned
getColumBreakpointIndexes({required BSColumn column}) → List<List<int>>
gets the breakpoint label indexes of a column, and the width factor of each breakpoint in the column breakpoint
of(BuildContext context) → BSRowInheritance
confirm the passed context contains BSRowInheritance, and if there is one, or more pass the nearest BSRowInheritance in the Widget tree use this function to access BSRowInheritance's data